---
title: 'Snk: A Snakemake Workflow Management System'
tags:
  - Python
  - Snakemake
  - Workflow
  - Bioinformatics
authors:
  - name: Wytamma Wirth
    orcid: 0000-0001-7070-0078
    affiliation: "1"
  - name: Robert Turnbull
    orcid: 0000-0003-1274-6750
    affiliation: "2"
  - name: Simon Mutch
    orcid: 0000-0002-3166-4614
    affiliation: "2"
affiliations:
 - name: Peter Doherty Institute for Infection and Immunity, University of Melbourne, Australia
   index: 1
 - name: Melbourne Data Analytics Platform, University of Melbourne, Melbourne 3010, Australia
   index: 2

date: 25 September 2024
bibliography: paper.bib
---

Snk (pronounced "snek") is a workflow management tool designed to simplify the use of complex Snakemake workflows by dynamically generating command-line interfaces (CLIs) for them. This software enables researchers and developers to integrate and manage sophisticated workflows seamlessly, turning them into modular components that can be executed and managed from the command line with minimal overhead. Snk significantly improves the interoperability and accessibility of Snakemake workflows, making it easier to use and share computational pipelines in various research fields.
